@@ -697,7 +697,7 @@ class ImportVisitor(DunderAllMixin, AttrsMixin, FastAPIMixin, PydanticMixin, ast
         elif isinstance(node, (ast.Tuple, ast.List)):
             for n in node.elts:
                 self.add_annotation(n)
-        elif isinstance(node, ast.Constant) and node.value is not None:
+        elif isinstance(node, ast.Constant) and isinstance(node.value, str):
             # Register annotation value
             setattr(node, ANNOTATION_PROPERTY, True)
             self.wrapped_annotations.append((node.lineno, node.col_offset, node.value))
@@ -731,8 +731,8 @@ class ImportVisitor(DunderAllMixin, AttrsMixin, FastAPIMixin, PydanticMixin, ast
     def visit_AnnAssign(self, node: ast.AnnAssign) -> None:
         """Remove all annotation assignments."""
         self.add_annotation(node.annotation)
-        if getattr(node, 'value', None):
-            self.generic_visit(node.value)  # type: ignore[arg-type]
+        if node_value := getattr(node, 'value', None):
+            self.visit(node_value)
 
     def register_function_ranges(self, node: Union[FunctionDef, AsyncFunctionDef]) -> None:
         """
@@ -920,6 +920,7 @@ class TypingOnlyImportsChecker:
 
                 # .. or whether there is another duplicate import inside the function scope
                 # (if the use is in a function scope)
+                use_in_function = False
                 if use.lineno in self.visitor.function_ranges:
                     for i in range(
                         self.visitor.function_ranges[use.lineno]['start'],
@@ -929,9 +930,11 @@ class TypingOnlyImportsChecker:
                             i in self.visitor.function_scope_imports
                             and import_name in self.visitor.function_scope_imports[i]['imports']
                         ):
-                            return
+                            use_in_function = True
+                            break
 
-                yield _import.lineno, 0, TC004.format(module=import_name), None
+                if not use_in_function:
+                    yield _import.lineno, 0, TC004.format(module=import_name), None
 
     def empty_type_checking_blocks(self) -> Flake8Generator:
         """TC005."""
